import React, { useState } from "react";

export default function App() {
    // State for inputs
    const [milesTraveled, setMilesTraveled] = useState(0);
    const [mpg, setMpg] = useState(0);
    const [pricePerGallon, setPricePerGallon] = useState(0);
    const [daysPerWeek, setDaysPerWeek] = useState(0);
    const [isRoundTrip, setIsRoundTrip] = useState(false);

    // State for results
    const [singleTripCost, setSingleTripCost] = useState(0);
    const [weeklyCost, setWeeklyCost] = useState(0);
    const [monthlyCost, setMonthlyCost] = useState(0);
    const [yearlyCost, setYearlyCost] = useState(0);

    const calculateCosts = () => {
        const milesPerDay = isRoundTrip ? milesTraveled * 2 : milesTraveled;
        const costPerMile = pricePerGallon / mpg;
        const tripCost = milesPerDay * costPerMile;
        
        setSingleTripCost(tripCost.toFixed(2));
        setWeeklyCost((tripCost * daysPerWeek).toFixed(2));
        setMonthlyCost((tripCost * daysPerWeek * (52/12)).toFixed(2));
        setYearlyCost((tripCost * daysPerWeek * 52).toFixed(2));
    };

    return (
        <div className="max-w-2xl mx-auto p-6 bg-white shadow-lg rounded-lg mt-10">
            <div className="space-y-4">
                <div>
                    <label htmlFor="milesTraveled" className="block text-sm font-medium text-gray-700">
                        Number of Miles Traveled
                    </label>
                    <input
                        type="number"
                        id="milesTraveled"
                        value={milesTraveled}
                        onChange={(e) => setMilesTraveled(e.target.value)}
                        className="mt-1 block w-full p-2 border border-gray-300 rounded-md shadow-sm focus:ring-blue-500 focus:border-blue-500"
                    />
                </div>

                <div>
                    <label htmlFor="mpg" className="block text-sm font-medium text-gray-700">
                        Miles per Gallon
                    </label>
                    <input
                        type="number"
                        id="mpg"
                        value={mpg}
                        onChange={(e) => setMpg(e.target.value)}
                        className="mt-1 block w-full p-2 border border-gray-300 rounded-md shadow-sm focus:ring-blue-500 focus:border-blue-500"
                    />
                </div>

                <div>
                    <label htmlFor="pricePerGallon" className="block text-sm font-medium text-gray-700">
                        Price per Gallon of Gas
                    </label>
                    <input
                        type="number"
                        step="0.01"
                        id="pricePerGallon"
                        value={pricePerGallon}
                        onChange={(e) => setPricePerGallon(e.target.value)}
                        className="mt-1 block w-full p-2 border border-gray-300 rounded-md shadow-sm focus:ring-blue-500 focus:border-blue-500"
                    />
                </div>

                <div>
                    <label htmlFor="daysPerWeek" className="block text-sm font-medium text-gray-700">
                        Number of Days per Week Traveled
                    </label>
                    <input
                        type="number"
                        id="daysPerWeek"
                        value={daysPerWeek}
                        onChange={(e) => setDaysPerWeek(e.target.value)}
                        className="mt-1 block w-full p-2 border border-gray-300 rounded-md shadow-sm focus:ring-blue-500 focus:border-blue-500"
                    />
                </div>

                <div className="flex items-center">
                    <input
                        type="checkbox"
                        id="roundTrip"
                        checked={isRoundTrip}
                        onChange={(e) => setIsRoundTrip(e.target.checked)}
                        className="h-4 w-4 text-blue-600 focus:ring-blue-500 border-gray-300 rounded"
                    />
                    <label htmlFor="roundTrip" className="ml-2 block text-sm font-medium text-gray-700">
                        Double numbers for round-trips
                    </label>
                </div>
            </div>

            <div className="mt-8 space-y-4">
                <div className="flex justify-between">
                    <span className="text-sm font-medium text-gray-700">Single Trip Cost:</span>
                    <span id="singleTripCost" className="text-sm text-gray-900">${singleTripCost}</span>
                </div>
                <div className="flex justify-between">
                    <span className="text-sm font-medium text-gray-700">Weekly Cost:</span>
                    <span id="weeklyCost" className="text-sm text-gray-900">${weeklyCost}</span>
                </div>
                <div className="flex justify-between">
                    <span className="text-sm font-medium text-gray-700">Monthly Cost:</span>
                    <span id="monthlyCost" className="text-sm text-gray-900">${monthlyCost}</span>
                </div>
                <div className="flex justify-between">
                    <span className="text-sm font-medium text-gray-700">Yearly Cost:</span>
                    <span id="yearlyCost" className="text-sm text-gray-900">${yearlyCost}</span>
                </div>
            </div>

            <div className="mt-8">
                <button
                    id="calculateButton"
                    onClick={calculateCosts}
                    className="w-full bg-blue-600 text-white py-2 rounded-md shadow-md hover:bg-blue-700 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-opacity-50"
                >
                    Calculate
                </button>
            </div>
        </div>
    );
}